@@ -20,35 +20,40 @@
 
 import collections
 import os
+import re
 
 import pytest
 
+from ansiblelint.config import options
+from ansiblelint.file_utils import Lintable
 from ansiblelint.rules import RulesCollection
 from ansiblelint.testing import run_ansible_lint
 
 
 @pytest.fixture
-def test_rules_collection():
+def test_rules_collection() -> RulesCollection:
     return RulesCollection([os.path.abspath('./test/rules')])
 
 
 @pytest.fixture
-def ematchtestfile():
-    return dict(path='test/ematchtest.yml', type='playbook')
+def ematchtestfile() -> Lintable:
+    return Lintable('examples/playbooks/ematcher-rule.yml', kind='playbook')
 
 
 @pytest.fixture
-def bracketsmatchtestfile():
-    return dict(path='test/bracketsmatchtest.yml', type='playbook')
+def bracketsmatchtestfile() -> Lintable:
+    return Lintable('examples/playbooks/bracketsmatchtest.yml', kind='playbook')
 
 
 def test_load_collection_from_directory(test_rules_collection):
-    assert len(test_rules_collection) == 2
+    # two detected rules plus the internal ones
+    assert len(test_rules_collection) == 5
 
 
 def test_run_collection(test_rules_collection, ematchtestfile):
     matches = test_rules_collection.run(ematchtestfile)
-    assert len(matches) == 3
+    assert len(matches) == 3  # 3 occurrences of BANNED using TEST0001
+    assert matches[0].linenumber == 2
 
 
 def test_tags(test_rules_collection, ematchtestfile, bracketsmatchtestfile):
@@ -57,7 +62,7 @@ def test_tags(test_rules_collection, ematchtestfile, bracketsmatchtestfile):
     matches = test_rules_collection.run(ematchtestfile, tags=['test2'])
     assert len(matches) == 0
     matches = test_rules_collection.run(bracketsmatchtestfile, tags=['test1'])
-    assert len(matches) == 1
+    assert len(matches) == 0
     matches = test_rules_collection.run(bracketsmatchtestfile, tags=['test2'])
     assert len(matches) == 2
 
@@ -70,7 +75,7 @@ def test_skip_tags(test_rules_collection, ematchtestfile, bracketsmatchtestfile)
     matches = test_rules_collection.run(bracketsmatchtestfile, skip_list=['test1'])
     assert len(matches) == 2
     matches = test_rules_collection.run(bracketsmatchtestfile, skip_list=['test2'])
-    assert len(matches) == 1
+    assert len(matches) == 0
 
 
 def test_skip_id(test_rules_collection, ematchtestfile, bracketsmatchtestfile):
@@ -81,7 +86,7 @@ def test_skip_id(test_rules_collection, ematchtestfile, bracketsmatchtestfile):
     matches = test_rules_collection.run(bracketsmatchtestfile, skip_list=['TEST0001'])
     assert len(matches) == 2
     matches = test_rules_collection.run(bracketsmatchtestfile, skip_list=['TEST0002'])
-    assert len(matches) == 1
+    assert len(matches) == 0
 
 
 def test_skip_non_existent_id(test_rules_collection, ematchtestfile):
@@ -90,7 +95,7 @@ def test_skip_non_existent_id(test_rules_collection, ematchtestfile):
 
 
 def test_no_duplicate_rule_ids(test_rules_collection):
-    real_rules = RulesCollection([os.path.abspath('./lib/ansiblelint/rules')])
+    real_rules = RulesCollection([os.path.abspath('./src/ansiblelint/rules')])
     rule_ids = [rule.id for rule in real_rules]
     assert not any(y > 1 for y in collections.Counter(rule_ids).values())
 
@@ -110,3 +115,17 @@ def test_rich_rule_listing():
         assert rule.shortdesc in result.stdout
         # description could wrap inside table, so we do not check full length
         assert rule.description[:30] in result.stdout
+
+
+def test_rules_id_format() -> None:
+    """Assure all our rules have consistent format."""
+    rule_id_re = re.compile("^[a-z-]{4,30}$")
+    options.enable_list = ['no-same-owner']
+    rules = RulesCollection(
+        [os.path.abspath('./src/ansiblelint/rules')], options=options
+    )
+    for rule in rules:
+        assert rule_id_re.match(
+            rule.id
+        ), f"R rule id {rule.id} did not match our required format."
+    assert len(rules) == 39
